.. See file COPYING distributed with unf for copyright and license.

unf contains Python code for Universal Numeric Fingerprints (UNFs)

http://guides.dataverse.org/en/latest/developers/unf/index.html
